@@ -114,6 +114,11 @@ def _x509():
     return ''
 
 
+# check if https
+def is_https(url):
+    return url.startswith('https://')
+
+
 # curl class
 class _Curl:
     # constructor
@@ -121,7 +126,10 @@ class _Curl:
         # path to curl
         self.path = 'curl'
         # verification of the host certificate
-        self.verifyHost = True
+        if 'PANDA_VERIFY_HOST' in os.environ and os.environ['PANDA_VERIFY_HOST'] == 'off':
+            self.verifyHost = False
+        else:
+            self.verifyHost = True
         # request a compressed response
         self.compress = True
         # SSL cert/key
@@ -131,10 +139,23 @@ class _Curl:
         self.verbose = False
         # use json
         self.use_json = False
-
+        # OIDC
+        if 'PANDA_AUTH' in os.environ and os.environ['PANDA_AUTH'] == 'oidc':
+            self.oidc = True
+            if 'PANDA_AUTH_VO' in os.environ:
+                self.authVO = os.environ['PANDA_AUTH_VO']
+            else:
+                self.authVO = None
+            if 'PANDA_AUTH_ID_TOKEN' in os.environ:
+                self.idToken = os.environ['PANDA_AUTH_ID_TOKEN']
+            else:
+                self.idToken = None
+        else:
+            self.oidc = False
 
     # GET method
-    def get(self,url,data):
+    def get(self, url, data):
+        use_https = is_https(url)
         # make command
         com = '%s --silent --get' % self.path
         if not self.verifyHost:
@@ -145,10 +166,16 @@ class _Curl:
             com += ' --capath /etc/grid-security/certificates'
         if self.compress:
             com += ' --compressed'
-        if self.sslCert != '':
+        if self.oidc:
+            com += ' -H "Authorization: Bearer {0}"'.format(self.idToken)
+            com += ' -H "Origin: {0}"'.format(self.authVO)
+        elif use_https:
+            if not self.sslCert:
+                self.sslCert = _x509()
             com += ' --cert %s' % self.sslCert
             com += ' --cacert %s' % self.sslCert
-        if self.sslKey != '':
+            if not self.sslKey:
+                self.sslKey = _x509()
             com += ' --key %s' % self.sslKey
         # timeout
         com += ' -m 600'
@@ -183,9 +210,9 @@ class _Curl:
             print(ret)
         return ret
 
-
     # POST method
     def post(self, url, data, via_file=False):
+        use_https = is_https(url)
         # make command
         com = '%s --silent' % self.path
         if not self.verifyHost:
@@ -196,10 +223,16 @@ class _Curl:
             com += ' --capath /etc/grid-security/certificates'
         if self.compress:
             com += ' --compressed'
-        if self.sslCert != '':
+        if self.oidc:
+            com += ' -H "Authorization: Bearer {0}"'.format(self.idToken)
+            com += ' -H "Origin: {0}"'.format(self.authVO)
+        elif use_https:
+            if not self.sslCert:
+                self.sslCert = _x509()
             com += ' --cert %s' % self.sslCert
             com += ' --cacert %s' % self.sslCert
-        if self.sslKey != '':
+            if not self.sslKey:
+                self.sslKey = _x509()
             com += ' --key %s' % self.sslKey
         # timeout
         com += ' -m 600'
@@ -243,9 +276,9 @@ class _Curl:
             print(ret)
         return ret
 
-
     # PUT method
-    def put(self,url,data):
+    def put(self, url, data):
+        use_https = is_https(url)
         # make command
         com = '%s --silent' % self.path
         if not self.verifyHost:
@@ -256,10 +289,16 @@ class _Curl:
             com += ' --capath /etc/grid-security/certificates'
         if self.compress:
             com += ' --compressed'
-        if self.sslCert != '':
+        if self.oidc:
+            com += ' -H "Authorization: Bearer {0}"'.format(self.idToken)
+            com += ' -H "Origin: {0}"'.format(self.authVO)
+        elif use_https:
+            if not self.sslCert:
+                self.sslCert = _x509()
             com += ' --cert %s' % self.sslCert
             com += ' --cacert %s' % self.sslCert
-        if self.sslKey != '':
+            if not self.sslKey:
+                self.sslKey = _x509()
             com += ' --key %s' % self.sslKey
         # emulate PUT
         for key in data:
@@ -2532,3 +2571,32 @@ def send_command_to_job(panda_id, com):
     except Exception as e:
         err_str = "ERROR send_command_to_job : {}".format(str(e))
         return EC_Failed, '{0}\n{1}'.format(output, err_str)
+
+
+# get ban list
+def get_ban_users(verbose=False):
+    """Get ban user list
+
+       args:
+           verbose: set True to see what's going on
+       returns:
+           status code
+                 True: communication succeeded to the panda server
+                 False: communication failure
+
+
+    """
+    # instantiate curl
+    curl = _Curl()
+    curl.verbose = verbose
+    # execute
+    url = baseURL + '/get_ban_users'
+    output = None
+    try:
+        status, output = curl.post(url, {})
+        if status == 0:
+            return json.loads(output)
+        else:
+            return False, "bad response: {}".format(output)
+    except Exception:
+        return False, "broken response: {}".format(output)
